==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerCaptureHTTPCookieFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IngressControllerCaptureHTTPCookieFluent<A extends IngressControllerCaptureHTTPCookieFluent<A>> extends BaseFluent<A>{
  public IngressControllerCaptureHTTPCookieFluent() {
  }
  public IngressControllerCaptureHTTPCookieFluent(IngressControllerCaptureHTTPCookie instance) {
    instance = (instance != null ? instance : new IngressControllerCaptureHTTPCookie());

    if (instance != null) {
      this.withMatchType(instance.getMatchType());
      this.withMaxLength(instance.getMaxLength());
      this.withName(instance.getName());
      this.withNamePrefix(instance.getNamePrefix());
      this.withMatchType(instance.getMatchType());
      this.withMaxLength(instance.getMaxLength());
      this.withName(instance.getName());
      this.withNamePrefix(instance.getNamePrefix());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String matchType;
  private Integer maxLength;
  private String name;
  private String namePrefix;
  private Map<String,Object> additionalProperties;
  public String getMatchType() {
    return this.matchType;
  }
  public A withMatchType(String matchType) {
    this.matchType=matchType; return (A) this;
  }
  public boolean hasMatchType() {
    return this.matchType != null;
  }
  public Integer getMaxLength() {
    return this.maxLength;
  }
  public A withMaxLength(Integer maxLength) {
    this.maxLength=maxLength; return (A) this;
  }
  public boolean hasMaxLength() {
    return this.maxLength != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getNamePrefix() {
    return this.namePrefix;
  }
  public A withNamePrefix(String namePrefix) {
    this.namePrefix=namePrefix; return (A) this;
  }
  public boolean hasNamePrefix() {
    return this.namePrefix != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerCaptureHTTPCookieFluent that = (IngressControllerCaptureHTTPCookieFluent) o;
    if (!java.util.Objects.equals(matchType, that.matchType)) return false;

    if (!java.util.Objects.equals(maxLength, that.maxLength)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(namePrefix, that.namePrefix)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchType,  maxLength,  name,  namePrefix,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchType != null) { sb.append("matchType:"); sb.append(matchType + ","); }
    if (maxLength != null) { sb.append("maxLength:"); sb.append(maxLength + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namePrefix != null) { sb.append("namePrefix:"); sb.append(namePrefix + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerCaptureHTTPCookieFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IngressControllerCaptureHTTPCookieFluent<A extends IngressControllerCaptureHTTPCookieFluent<A>> extends BaseFluent<A>{
  public IngressControllerCaptureHTTPCookieFluent() {
  }
  
  public IngressControllerCaptureHTTPCookieFluent(IngressControllerCaptureHTTPCookie instance) {
    this.copyInstance(instance);
  }
  private String matchType;
  private Integer maxLength;
  private String name;
  private String namePrefix;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(IngressControllerCaptureHTTPCookie instance) {
    instance = (instance != null ? instance : new IngressControllerCaptureHTTPCookie());
  
    if (instance != null) {
        this.withMatchType(instance.getMatchType());
        this.withMaxLength(instance.getMaxLength());
        this.withName(instance.getName());
        this.withNamePrefix(instance.getNamePrefix());
        this.withMatchType(instance.getMatchType());
        this.withMaxLength(instance.getMaxLength());
        this.withName(instance.getName());
        this.withNamePrefix(instance.getNamePrefix());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getMatchType() {
    return this.matchType;
  }
  
  public A withMatchType(String matchType) {
    this.matchType=matchType; return (A) this;
  }
  
  public boolean hasMatchType() {
    return this.matchType != null;
  }
  
  public Integer getMaxLength() {
    return this.maxLength;
  }
  
  public A withMaxLength(Integer maxLength) {
    this.maxLength=maxLength; return (A) this;
  }
  
  public boolean hasMaxLength() {
    return this.maxLength != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getNamePrefix() {
    return this.namePrefix;
  }
  
  public A withNamePrefix(String namePrefix) {
    this.namePrefix=namePrefix; return (A) this;
  }
  
  public boolean hasNamePrefix() {
    return this.namePrefix != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerCaptureHTTPCookieFluent that = (IngressControllerCaptureHTTPCookieFluent) o;
    if (!java.util.Objects.equals(matchType, that.matchType)) return false;
  
    if (!java.util.Objects.equals(maxLength, that.maxLength)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(namePrefix, that.namePrefix)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(matchType,  maxLength,  name,  namePrefix,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchType != null) { sb.append("matchType:"); sb.append(matchType + ","); }
    if (maxLength != null) { sb.append("maxLength:"); sb.append(maxLength + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namePrefix != null) { sb.append("namePrefix:"); sb.append(namePrefix + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
